┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/panels/folders/treeviewcontextmenu.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/panels/folders/treeviewcontextmenu.h')
-rw-r--r--src/panels/folders/treeviewcontextmenu.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/panels/folders/treeviewcontextmenu.h b/src/panels/folders/treeviewcontextmenu.h
index e33bb70c5..0b3fd79bd 100644
--- a/src/panels/folders/treeviewcontextmenu.h
+++ b/src/panels/folders/treeviewcontextmenu.h
@@ -50,25 +50,25 @@ public:
void open();
private slots:
/** Cuts the item m_fileInfo. */
void cut();
/** Copies the item m_fileInfo. */
void copy();
/** Paste the clipboard to m_fileInfo. */
void paste();
/** Renames the item m_fileInfo. */
void rename();
/** Moves the item m_fileInfo to the trash. */
void moveToTrash();
/** Deletes the item m_fileInfo. */
void deleteItem();
/** Shows the properties of the item m_fileInfo. */
void showProperties();
/**
@@ -88,7 +88,7 @@ private:
private:
FoldersPanel* m_parent;
- KFileItem m_fileInfo;
+ KFileItem m_fileItem;
};
#endif
@@ -50,25 +50,25 @@ public:
void open();
private slots:
- /** Cuts the item m_fileInfo. */
+ /** Cuts the item m_fileItem. */
void cut();
@@ -50,25 +50,25 @@ public:
void cut();
- /** Copies the item m_fileInfo. */
+ /** Copies the item m_fileItem. */
void copy();
@@ -50,25 +50,25 @@ public:
void copy();
- /** Paste the clipboard to m_fileInfo. */
+ /** Paste the clipboard to m_fileItem. */
void paste();
@@ -50,25 +50,25 @@ public:
void paste();
- /** Renames the item m_fileInfo. */
+ /** Renames the item m_fileItem. */
void rename();
@@ -50,25 +50,25 @@ public:
void rename();
- /** Moves the item m_fileInfo to the trash. */
+ /** Moves the item m_fileItem to the trash. */
void moveToTrash();
@@ -50,25 +50,25 @@ public:
void moveToTrash();
- /** Deletes the item m_fileInfo. */
+ /** Deletes the item m_fileItem. */
void deleteItem();
@@ -50,25 +50,25 @@ public:
void deleteItem();
- /** Shows the properties of the item m_fileInfo. */
+ /** Shows the properties of the item m_fileItem. */
void showProperties();
/**